sccoda.model.other\_models
==========================

.. automodule:: sccoda.model.other_models

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
   
      PoissonModel
      SimpleModel
      scdney_model
   
   

   
   
   